<?php

namespace edu\wisc\doit\uwphps\local;

use edu\wisc\doit\uwphps\preauth\PreauthUserDetailsProvider;
use edu\wisc\doit\uwphps\UWUserDetails;

/**
 * LocalUserDetailsProvider provides a developer with a {@link UWUserDetails} suitable for use in local development.
 */
class LocalUserDetailsProvider extends PreauthUserDetailsProvider
{

    /** @var string */
    private $filePath;

    /**
     * LocalUserDetailsProvider constructor.
     *
     * @param $filePath string Path to JSON file defining a local user.
     */
    public function __construct($filePath)
    {
        parent::__construct(false);
        $this->filePath = $filePath;
    }

    /**
     * {@inheritdoc}
     */
    public function loadUser()
    {
        $jsonString = file_get_contents($this->filePath);
        if ($jsonString === false) {
            return null;
        }

        $attributes = json_decode($jsonString, true);

        return new UWUserDetails(
            $attributes[static::EPPN],
            $attributes[static::PVI],
            $attributes[static::FULL_NAME],
            explode(static::DELIMITER, $attributes[static::UDDS]),
            $attributes[static::EMAIL],
            $attributes[static::SOURCE],
            $attributes[static::ISIS_EMPLID],
            $attributes[static::FIRST_NAME],
            $attributes[static::LAST_NAME]
        );
    }

    /**
     * Get the path of the local user JSON file.
     *
     * @return string
     */
    public function getFilePath()
    {
        return $this->filePath;
    }

    /**
     * Set the path of the local user JSON file.
     * @param $filePath
     */
    public function setFilePath($filePath)
    {
        $this->filePath = $filePath;
    }

}