<?php

namespace edu\wisc\doit\uwphps\preauth;

use edu\wisc\doit\uwphps\UserDetailsProvider;
use edu\wisc\doit\uwphps\UWUserDetails;

/**
 * FederatedPreauthUserDetailsProvider is an implementation of {@link UserDetailsProvider} for loading users
 * authenticated with UW-System Federated login.
 *
 * {@see PreauthUserDetailsProvider} for loading users authenticated through UW-Madison login.
 */
class FederatedPreauthUserDetailsProvider extends UserDetailsProvider
{

    // Constants defining common header values
    const SPVI = "eduWisconsinSPVI";
    const EMAIL = "eduWisconsinEmailAddress";
    const FULL_NAME = "eduWisconsinCommonName";
    const FIRST_NAME = "eduWisconsinGivenName";
    const LAST_NAME = "eduWisconsinSurname";

    /**
     * {@inheritdoc}
     */
    public function loadUser()
    {
        // Return null if no Shib session is found
        if (($this->httpHeaders && !getenv(static::SHIB_SESSION_ID_HTTP)) ||
            (!$this->httpHeaders && !getenv(static::SHIB_SESSION_ID))) {
            return null;
        }

        if ($this->httpHeaders) {
            $userDetails = new UWUserDetails(
                getenv(UserDetailsProvider::httpHeaderFromAttribute(static::EPPN)),
                getenv(UserDetailsProvider::httpHeaderFromAttribute(static::SPVI)),
                getenv(UserDetailsProvider::httpHeaderFromAttribute(static::FULL_NAME)),
                explode(static::DELIMITER, getenv(UserDetailsProvider::httpHeaderFromAttribute(static::UDDS))),
                getenv(UserDetailsProvider::httpHeaderFromAttribute(static::EMAIL)),
                getenv(UserDetailsProvider::httpHeaderFromAttribute(static::SOURCE)),
                getenv(UserDetailsProvider::httpHeaderFromAttribute(static::ISIS_EMPLID)),
                getenv(UserDetailsProvider::httpHeaderFromAttribute(static::FIRST_NAME)),
                getenv(UserDetailsProvider::httpHeaderFromAttribute(static::LAST_NAME))
            );
        } else {
            $userDetails = new UWUserDetails(
                getenv(static::EPPN),
                getenv(static::SPVI),
                getenv(static::FULL_NAME),
                getenv(static::UDDS),
                getenv(static::EMAIL),
                getenv(static::SOURCE),
                getenv(static::ISIS_EMPLID),
                getenv(static::FIRST_NAME),
                getenv(static::LAST_NAME)
            );
        }

        return $userDetails;
    }

}
